OeditusCredo.Check.Refactoring.AvoidSinglePipe (OeditusCredo v0.11.1)

Basics

This check is disabled by default.

Learn how to enable it via .credo.exs.

This check has a base priority of low and works with any version of Elixir.

Explanation

Single-stage pipes (data |> String.trim()) add unnecessary syntax. Pipes should only be used to chain 2 or more function calls.

Bad:

data |> String.trim()

Good:

String.trim(data)

Check-Specific Parameters

Use the following parameters to configure this check:

:exclude_test_files

Set to true to skip test files (default: false)

This parameter defaults to nil.

General Parameters

Like with all checks, general params can be applied.

Parameters can be configured via the .credo.exs config file.