OeditusCredo.Check.Refactoring.PreferCasePatternMatching (OeditusCredo v0.11.1)

Basics

This check is disabled by default.

Learn how to enable it via .credo.exs.

This check has a base priority of normal and works with any version of Elixir.

Explanation

Using if or cond for tagged tuples, atoms, or repeating variable equality checks obscures structural pattern matching.

Bad:

if status == {:ok, data} do
  process(data)
else
  handle_error()
end

Good:

case status do
  {:ok, data} -> process(data)
  _ -> handle_error()
end

Check-Specific Parameters

Use the following parameters to configure this check:

:exclude_test_files

Set to true to skip test files (default: false)

This parameter defaults to nil.

General Parameters

Like with all checks, general params can be applied.

Parameters can be configured via the .credo.exs config file.