OeditusCredo.Check.Refactoring.PreferDestructuring (OeditusCredo v0.11.1)

Basics

This check is disabled by default.

Learn how to enable it via .credo.exs.

This check has a base priority of normal and works with any version of Elixir.

Explanation

Calling elem/2 or Map.get/2 to extract data from tuples or maps obscures pattern matching.

Bad:

status = elem(result, 0)
name = Map.get(user, :name)

Good:

{:ok, payload} = result
%{name: name} = user

Check-Specific Parameters

Use the following parameters to configure this check:

:exclude_test_files

Set to true to skip test files (default: false)

This parameter defaults to nil.

General Parameters

Like with all checks, general params can be applied.

Parameters can be configured via the .credo.exs config file.