OeditusCredo.Check.Refactoring.PreferDotAccessForStructs (OeditusCredo v0.11.1)

Basics

This check is disabled by default.

Learn how to enable it via .credo.exs.

This check has a base priority of normal and works with any version of Elixir.

Explanation

Bracket access syntax struct[:field] on structs is unidiomatic and fails at runtime unless Access is implemented. Use dot notation struct.field or pattern matching destructuring instead.

Bad:

user[:name]

Good:

user.name
# Or: %User{name: name} = user

Check-Specific Parameters

Use the following parameters to configure this check:

:exclude_test_files

Set to true to skip test files (default: false)

This parameter defaults to nil.

General Parameters

Like with all checks, general params can be applied.

Parameters can be configured via the .credo.exs config file.