OeditusCredo.Check.Refactoring.PreferFunctionCapture (OeditusCredo v0.11.1)

Basics

This check is disabled by default.

Learn how to enable it via .credo.exs.

This check has a base priority of low and works with any version of Elixir.

Explanation

Wrapping single function calls in anonymous functions fn x -> String.trim(x) end adds unnecessary syntax. Use function capture &String.trim/1.

Bad:

Enum.map(inputs, fn str -> String.trim(str) end)

Good:

Enum.map(inputs, &String.trim/1)

Check-Specific Parameters

Use the following parameters to configure this check:

:exclude_test_files

Set to true to skip test files (default: false)

This parameter defaults to nil.

General Parameters

Like with all checks, general params can be applied.

Parameters can be configured via the .credo.exs config file.