OeditusCredo.Check.Refactoring.PreferInplaceMapMatching (OeditusCredo v0.11.1)

Basics

This check is disabled by default.

Learn how to enable it via .credo.exs.

This check has a base priority of normal and works with any version of Elixir.

Explanation

Guarding is_map(arg) in function definitions is redundant when you can pattern match %{} or %{} = arg directly in the parameter list.

Bad:

def process(opts) when is_map(opts) do
  ...
end

Good:

def process(%{} = opts) do
  ...
end

Check-Specific Parameters

Use the following parameters to configure this check:

:exclude_test_files

Set to true to skip test files (default: false)

This parameter defaults to nil.

General Parameters

Like with all checks, general params can be applied.

Parameters can be configured via the .credo.exs config file.