OeditusCredo.Check.Refactoring.PreferListPrepend (OeditusCredo v0.11.1)

Basics

This check is disabled by default.

Learn how to enable it via .credo.exs.

This check has a base priority of high and works with any version of Elixir.

Explanation

Appending to a list (list ++ [item]) traverses the entire list (O(N)), leading to quadratic runtime in loops. Prepend [item | list] in O(1) and reverse at the end.

Bad:

acc = acc ++ [new_item]

Good:

acc = [new_item | acc]
# Enum.reverse(acc)

Check-Specific Parameters

Use the following parameters to configure this check:

:exclude_test_files

Set to true to skip test files (default: false)

This parameter defaults to nil.

General Parameters

Like with all checks, general params can be applied.

Parameters can be configured via the .credo.exs config file.