OeditusCredo.Check.Refactoring.PreferMapMerge (OeditusCredo v0.11.1)

Basics

This check is disabled by default.

Learn how to enable it via .credo.exs.

This check has a base priority of normal and works with any version of Elixir.

Explanation

Chaining multiple Map.put calls for literal keys is inefficient and verbose. Use Map.merge(map, %{key: val}).

Bad:

map |> Map.put(:a, 1) |> Map.put(:b, 2)

Good:

Map.merge(map, %{a: 1, b: 2})

Check-Specific Parameters

Use the following parameters to configure this check:

:exclude_test_files

Set to true to skip test files (default: false)

This parameter defaults to nil.

General Parameters

Like with all checks, general params can be applied.

Parameters can be configured via the .credo.exs config file.