OeditusCredo.Check.Refactoring.PreferMultiHeadForNil (OeditusCredo v0.11.1)

Basics

This check is disabled by default.

Learn how to enable it via .credo.exs.

This check has a base priority of normal and works with any version of Elixir.

Explanation

Checking is_nil/1 in guards is unnecessary when pattern matching nil directly in multi-head functions.

Bad:

def process(val) when not is_nil(val) do
  ...
end

Good:

def process(nil), do: :error
def process(val), do: do_process(val)

Check-Specific Parameters

Use the following parameters to configure this check:

:exclude_test_files

Set to true to skip test files (default: false)

This parameter defaults to nil.

General Parameters

Like with all checks, general params can be applied.

Parameters can be configured via the .credo.exs config file.