OeditusCredo.Check.Refactoring.PreferMultiHeadFunction (OeditusCredo v0.11.1)

Basics

This check is disabled by default.

Learn how to enable it via .credo.exs.

This check has a base priority of normal and works with any version of Elixir.

Explanation

Branching on function arguments inside the function body with if or cond violates Elixir's multi-head function idiom.

Bad:

def process(mode) do
  if mode == :fast do
    run_fast()
  else
    run_slow()
  end
end

Good:

def process(:fast), do: run_fast()
def process(:slow), do: run_slow()

Check-Specific Parameters

Use the following parameters to configure this check:

:exclude_test_files

Set to true to skip test files (default: false)

This parameter defaults to nil.

General Parameters

Like with all checks, general params can be applied.

Parameters can be configured via the .credo.exs config file.