OeditusCredo.Check.Refactoring.PreferPatternMatchingForEmptiness (OeditusCredo v0.11.1)

Basics

This check is disabled by default.

Learn how to enable it via .credo.exs.

This check has a base priority of high and works with any version of Elixir.

Explanation

Enum.count/1 traverses the full list to calculate count just to check if it's empty or non-empty. Use pattern matching [_ | _] or [] instead.

Bad:

if Enum.count(list) > 0 do ... end

Good:

case list do
  [_ | _] -> ...
  [] -> ...
end

Check-Specific Parameters

Use the following parameters to configure this check:

:exclude_test_files

Set to true to skip test files (default: false)

This parameter defaults to nil.

General Parameters

Like with all checks, general params can be applied.

Parameters can be configured via the .credo.exs config file.