OeditusCredo.Check.Refactoring.PreferShortFieldAccessCapture (OeditusCredo v0.11.1)

Basics

This check is disabled by default.

Learn how to enable it via .credo.exs.

This check has a base priority of low and works with any version of Elixir.

Explanation

Verbose anonymous function fn x -> x.field end for extracting a field can be shortened to & &1.field.

Bad:

Enum.map(users, fn u -> u.id end)

Good:

Enum.map(users, & &1.id)

Check-Specific Parameters

Use the following parameters to configure this check:

:exclude_test_files

Set to true to skip test files (default: false)

This parameter defaults to nil.

General Parameters

Like with all checks, general params can be applied.

Parameters can be configured via the .credo.exs config file.