OeditusCredo.Check.Refactoring.PreferTaggedTuplesForErrors (OeditusCredo v0.11.1)

Basics

This check is disabled by default.

Learn how to enable it via .credo.exs.

This check has a base priority of normal and works with any version of Elixir.

Explanation

Using try...rescue for ordinary control flow is inefficient on BEAM. Prefer safe functions returning tagged tuples {:ok, val} / {:error, reason}.

Bad:

try do
  String.to_integer(str)
rescue
  ArgumentError -> :invalid
end

Good:

case Integer.parse(str) do
  {num, ""} -> {:ok, num}
  _ -> :invalid
end

Check-Specific Parameters

Use the following parameters to configure this check:

:exclude_test_files

Set to true to skip test files (default: false)

This parameter defaults to nil.

General Parameters

Like with all checks, general params can be applied.

Parameters can be configured via the .credo.exs config file.