OeditusCredo.Check.Refactoring.PreferWithClause (OeditusCredo v0.11.1)

Basics

This check is disabled by default.

Learn how to enable it via .credo.exs.

This check has a base priority of high and works with any version of Elixir.

Explanation

Deeply nested case statements create unreadable code. Use with to chain sequential fallible operations cleanly.

Bad:

case step1() do
  {:ok, res1} ->
    case step2(res1) do
      {:ok, res2} -> {:ok, res2}
      {:error, err} -> {:error, err}
    end
  {:error, err} -> {:error, err}
end

Good:

with {:ok, res1} <- step1(),
     {:ok, res2} <- step2(res1) do
  {:ok, res2}
end

Check-Specific Parameters

Use the following parameters to configure this check:

:exclude_test_files

Set to true to skip test files (default: false)

This parameter defaults to nil.

General Parameters

Like with all checks, general params can be applied.

Parameters can be configured via the .credo.exs config file.