OeditusCredo.Check.Refactoring.PreferForComprehensionOverFilterMap
(OeditusCredo v0.11.1)
Basics
This check is disabled by default.
Learn how to enable it via .credo.exs.
This check has a base priority of normal and works with any version of Elixir.
Explanation
Piping Enum.filter into Enum.map (or vice-versa) iterates over the list twice and allocates intermediate lists.
Bad:
list |> Enum.filter(&valid?/1) |> Enum.map(&transform/1)Good:
for item <- list, valid?(item), do: transform(item)Check-Specific Parameters
Use the following parameters to configure this check:
:exclude_test_files
Set to true to skip test files (default: false)
This parameter defaults to nil.
General Parameters
Like with all checks, general params can be applied.
Parameters can be configured via the .credo.exs config file.