OeditusCredo.Check.Refactoring.PreferInplaceBinaryMatching
(OeditusCredo v0.11.1)
Basics
This check is disabled by default.
Learn how to enable it via .credo.exs.
This check has a base priority of normal and works with any version of Elixir.
Explanation
Checking binary type and non-emptiness in guards can be replaced with direct
binary pattern matching in the function parameter list: <<_::utf8, _::binary>> or <<_, _::binary>>.
Bad:
def process(str) when is_binary(str) and str != "" do
...
endGood:
def process(<<_::utf8, _::binary>> = str) do
...
endCheck-Specific Parameters
Use the following parameters to configure this check:
:exclude_test_files
Set to true to skip test files (default: false)
This parameter defaults to nil.
General Parameters
Like with all checks, general params can be applied.
Parameters can be configured via the .credo.exs config file.