OeditusCredo.Check.Refactoring.PreferPipelineOperator
(OeditusCredo v0.11.1)
Basics
This check is disabled by default.
Learn how to enable it via .credo.exs.
This check has a base priority of normal and works with any version of Elixir.
Explanation
Assigning intermediate results to temporary variables just to pass them as the first argument in the next line is unidiomatic in Elixir.
Bad:
step1 = String.trim(input)
step2 = String.downcase(step1)
step3 = String.reverse(step2)Good:
input
|> String.trim()
|> String.downcase()
|> String.reverse()Check-Specific Parameters
Use the following parameters to configure this check:
:exclude_test_files
Set to true to skip test files (default: false)
This parameter defaults to nil.
General Parameters
Like with all checks, general params can be applied.
Parameters can be configured via the .credo.exs config file.